/*
  stores deviceConfig data
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */



#ifndef __DEVICECONFIG_H
#define __DEVICECONFIG_H

#include <iostream.h>
#include <deviceConfig/yafAudioInfo.h>
#include <deviceConfig/musicInfo.h>
#include <deviceConfig/statusInfo.h>
#include <deviceConfig/audioBuffer.h>


/**
  DeviceConfig stores all the data which may be useful for a device.
  It stores the PCM data. The samplespeed (44.1KHz) etc...
  <p>
  A device can handle stream data (audio,video). But not
  every device is interested in all data. An audioDevice
  for example only is interested in the speed/sampleSize/stereo
  and a multicast device is not interested in the data at all.
  <p>
  But not all configuration options should be in the 
  device config. Only these which are important for the 
  stream data (the meta data) is in the deviceConfig.
  For example a spectrumAnalyser device has the configuartion
  options: -number of bands.
  <p>
  This is not important for the stream. Thus this data
  is stored not in this structure.

*/


#define _DEFAULT_BUFFERSIZE 4096


class DeviceConfig {

  YafAudioInfo* audioInfo;
  MusicInfo* musicInfo;
  StatusInfo* statusInfo;
  AudioBuffer* audioBuffer;
  void* streamProducer;
  
 public:
  DeviceConfig();
  ~DeviceConfig();

  void copyTo(DeviceConfig* aConfig);

  void setAudioInfo(YafAudioInfo* audioInfo); 
  YafAudioInfo* getAudioInfo(); 
  
  void setMusicInfo(MusicInfo* musicInfo);
  MusicInfo* getMusicInfo();

  
  void setStatusInfo(StatusInfo* statusInfo);
  StatusInfo* getStatusInfo();

  void setAudioBuffer(AudioBuffer* aBuffer); 
  AudioBuffer* getAudioBuffer(); 
 
  // streamProducer are stored as a void pointer because
  // of a recursive inclusion!
  // you should safley cast it where you need it.
  void* getStreamProducer();
  void setStreamProducer(void* streamProducer);

  void print();

};



#endif
