//
//  Kmpg
// 
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef TRACKCALENDAR_H
#define TRACKCALENDAR_H

#include <qwidget.h>
#include <qlist.h>

#include "led.h"
#include "playlistmgr.h"

class TrackCalendarArrow : public QWidget
{
      Q_OBJECT
   public:
      enum Direction { Up, Down };
      TrackCalendarArrow( QWidget*, Direction );
   protected:
      virtual void paintEvent( QPaintEvent* );
      virtual void mousePressEvent( QMouseEvent* );
   signals:
      void clicked();
   private:
      Direction _direction;
};

class TrackCalendarItem : public QWidget, public Led
{
      Q_OBJECT
   public:
      TrackCalendarItem( QWidget*, int, KURL );
      virtual void setPlayed( bool pl ) { _played = pl; repaint(); };
      virtual bool isPlayed() { return _played; repaint(); };
      virtual void setIndex( int i ) 
      { 
	 _index = i; 
	 adjustSize(); 
	 if( isVisible() )
	    repaint(); 
      };
      virtual void adjustSize();
   signals:
      void sigSelected( int );
   protected:
      virtual void paintEvent( QPaintEvent* );
      virtual void mousePressEvent( QMouseEvent* );
   private:
      bool _played;
      int _index;
      KURL _url;
};

class TrackCalendar : public QWidget
{
      Q_OBJECT
   public:
      TrackCalendar( QWidget*, PlaylistMgr* );
      ~TrackCalendar();
   signals:
      void sigSizeChanged();
   public slots:
      void arrowDown();
      void arrowUp();
      void doClear();
      void doInsert( int, QString );
      void doUpdate( int, QString );
      void doRemove( int );
      void doMoveUp( int );
      void doMoveDown( int );
      void doSetPlayed( int, bool );
      void doSetAllPlayed( bool );
      void doTrackSelected( int );
   private:
      void positionTrack( int );
      void resizeCalendar();
   protected:
      QList<TrackCalendarItem> _list;
      PlaylistMgr *_mgr;
      QWidget *_panel;
      TrackCalendarArrow *_arrowUp, *_arrowDown;
      int _rows, _toprow;
};


#endif
